@@ -1,6 +1,6 @@
 # coding: utf-8
 # create by tongshiwei on 2019/4/7
 
-from .ValueMonitor import MovingValue
+from .ValueMonitor import EMAValue
 from .LossMonitor import MovingLoss
 from .ProgressMonitor import ConsoleProgressMonitor
