@@ -143,6 +143,51 @@ def var2exp(var_str, env_wrap=lambda x: x):
     return exp
 
 
+def is_classmethod(method):
+    """
+
+    Parameters
+    ----------
+    method
+
+    Returns
+    -------
+
+    Examples
+    --------
+    >>> class A:
+    ...     def a(self):
+    ...         pass
+    ...     @staticmethod
+    ...     def b():
+    ...         pass
+    ...     @classmethod
+    ...     def c(cls):
+    ...         pass
+    >>> obj = A()
+    >>> is_classmethod(obj.a)
+    False
+    >>> is_classmethod(obj.b)
+    False
+    >>> is_classmethod(obj.c)
+    True
+    >>> def fun():
+    ...     pass
+    >>> is_classmethod(fun)
+    False
+    """
+    bound_to = getattr(method, '__self__', None)
+    if not isinstance(bound_to, type):
+        # must be bound to a class
+        return False
+    name = method.__name__
+    for cls in bound_to.__mro__:
+        descriptor = vars(cls).get(name)
+        if descriptor is not None:
+            return isinstance(descriptor, classmethod)
+    return False
+
+
 class Configuration(object):
     """自定义的配置文件基类"""
 
@@ -406,6 +451,21 @@ class ConfigurationParser(argparse.ArgumentParser):
     >>> parser = ConfigurationParser(TestCC)
     >>> parser("--c _c=int(3);_d=float(0.3)")
     {'c': {'_c': 3, '_d': 0.3}}
+    >>> class TestCls:
+    ...     def a(self, a=1):
+    ...         return a
+    ...     @staticmethod
+    ...     def b(b=2):
+    ...         return b
+    ...     @classmethod
+    ...     def c(cls, c=3):
+    ...         return c
+    >>> parser = ConfigurationParser(TestCls, commands=[TestCls.b, TestCls.c])
+    >>> parser("b")
+    {'b': 2, 'subcommand': 'b'}
+    >>> parser("c")
+    {'c': 3, 'subcommand': 'c'}
+
     """
 
     def __init__(self, class_type, excluded_names: (set, None) = None, commands=None, *args, **kwargs):
@@ -519,8 +579,10 @@ class ConfigurationParser(argparse.ArgumentParser):
     def func_spec(f):
         """获取函数参数表"""
         argspec = inspect.getfullargspec(f)
+        argspec_args = argspec.args[1:] if is_classmethod(f) else argspec.args
+
         return f.__name__, args_zips(
-            argspec.args, argspec.defaults
+            argspec_args, argspec.defaults
         ) + args_zips(
             argspec.kwonlyargs,
             argspec.kwonlydefaults.values() if argspec.kwonlydefaults else []
@@ -647,3 +709,16 @@ class Formatter(object):
     def format(*format_string, formatter=None):
         formatter = Formatter(formatter)
         return formatter(*format_string)
+
+
+if __name__ == '__main__':
+    class TestCls(Configuration):
+        a = 1
+
+        @classmethod
+        def cls_m(cls, new_a):
+            cls.a = new_a
+
+    parser = ConfigurationParser(TestCls)
+    parser.add_command(TestCls.cls_m)
+    print(parser("cls_m 1"))
