@@ -2,18 +2,21 @@
 # create by tongshiwei on 2019-8-27
 
 import functools
+
 import fire
 
-from longling.lib.stream import encode
-from longling.ML.toolkit.dataset import train_valid_test, train_test, train_valid, kfold
-from longling.ML.toolkit.analyser.cli import select_max, arg_select_max
-from longling.ML.toolkit.hyper_search.nni import show_top_k, show
-from longling.toolbox import toc
-from longling.Architecture.cli import cli as arch
 from longling import Architecture as arch_cli
+from longling.Architecture.cli import cli as arch
 from longling.Architecture.install_file import nni as install_nni
-from longling.lib.loading import csv2json, json2csv
+from longling.ML import embedding_dim
+from longling.ML.toolkit.analyser.cli import select_max, arg_select_max, select_min, arg_select_min
+from longling.ML.toolkit.analyser.to_board import to_board
+from longling.ML.toolkit.dataset import train_valid_test, train_test, kfold
+from longling.ML.toolkit.hyper_search.nni import show_top_k, show
+from longling.lib.loading import csv2jsonl, jsonl2csv
+from longling.lib.stream import encode
 from longling.spider import download_file as download
+from longling.toolbox import toc
 
 tarch = functools.partial(arch, author="Shiwei Tong")
 
@@ -23,7 +26,6 @@ def cli():  # pragma: no cover
         {
             "train_valid_test": train_valid_test,
             "train_test": train_test,
-            "train_valid": train_valid,
             "kfold": kfold,
             "toc": toc,
             "arch": arch,
@@ -31,8 +33,10 @@ def cli():  # pragma: no cover
             "arch-cli": arch_cli,
             "max": select_max,
             "amax": arg_select_max,
-            "csv2json": csv2json,
-            "json2csv": json2csv,
+            "min": select_min,
+            "amin": arg_select_min,
+            "csv2jsonl": csv2jsonl,
+            "jsonl2csv": jsonl2csv,
             "encode": encode,
             "download": download,
             "nni": {
@@ -41,6 +45,10 @@ def cli():  # pragma: no cover
             },
             "install": {
                 "nni": install_nni,
+            },
+            "to_board": to_board,
+            "ml": {
+                "embedding_dim": embedding_dim,
             }
         }
     )
